﻿import es
import gamethread
import langlib
import math
import playerlib
import popuplib
import random

common = langlib.Strings("cstrike/addons/eventscripts/soccer_mod_2010/language/common.ini")
messages = langlib.Strings("cstrike/addons/eventscripts/soccer_mod_2010/language/match/messages_match.ini")

# ******************** Load ********************
def load():
	load_variables()
	create_popup()

	es.load("soccer_mod_2010/match/names")
	es.load("soccer_mod_2010/match/score")
	es.load("soccer_mod_2010/match/time")

	check = es.ServerVar("sm_module_match_stats_on")
	if check == 1:
		es.load("soccer_mod_2010/match/stats")

# ******************** Load variables ********************
def load_variables():
	es.set("match", 0)
	es.set("match_paused", 0)
	es.set("period", 0)
	es.set("period_time", 0)
	es.set("minutes", 0)
	es.set("seconds", 0)
	es.set("period_running", 0)
	es.set("period_break_running", 0)
	es.set("golden_goal", 0)
	es.set("match_toss", 0)

# ******************** Create popup ********************
def create_popup():
	text = langlib.Strings("cstrike/addons/eventscripts/soccer_mod_2010/language/match/popup_admin_match.ini")

	popup = popuplib.create("sm_popup_admin_match")

	line = "SOCCER MOD %s" % (text("title"))
	popup.addline(line)

	popup.addline(" ")

	line = "->1. %s" % (text("start"))
	popup.addline(line)

	line = "->2. %s" % (text("pause"))
	popup.addline(line)

	line = "->3. %s" % (text("unpause"))
	popup.addline(line)

	line = "->4. %s" % (text("stop"))
	popup.addline(line)

	line = "->5. %s" % (text("names"))
	popup.addline(line)

	line = "->6. %s" % (text("score"))
	popup.addline(line)

	popup.addline(" ")

	line = "->9. %s" % (common("back"))
	popup.addline(line)

	popup.addline(" ")

	line = "->0. %s" % (common("close"))
	popup.addline(line)

	popup.select(1, popup_match_start)
	popup.select(2, popup_match_pause)
	popup.select(3, popup_match_unpause)
	popup.select(4, popup_match_stop)
	popup.submenu(5, "sm_popup_admin_match_names")
	popup.submenu(6, "sm_popup_admin_match_score")
	popup.submenu(7, "sm_popup_admin_match")
	popup.submenu(8, "sm_popup_admin_match")
	popup.submenu(9, "sm_popup_admin")

# ******************** Events ********************
def round_start(event_var):
	enabled = es.ServerVar("soccer_mod_allowed")
	if enabled == 1:
		match_paused = es.ServerVar("match_paused")
		period_break_running = es.ServerVar("period_break_running")
		if match_paused == 1 or period_break_running == 1:
			freeze_match()
		else:
			unfreeze_match()

		check = es.ServerVar("sm_match_sounds_on")
		if check == 1:
			sound = es.ServerVar("sm_match_sound_round_start")
			es.cexec_all("playgamesound", sound)

def round_end(event_var):
	enabled = es.ServerVar("soccer_mod_allowed")
	if enabled == 1:
		check = es.ServerVar("sm_match_sounds_on")
		if check == 1:
			sound = es.ServerVar("sm_match_sound_round_end")
			es.cexec_all("playgamesound", sound)

# ******************** Commands ********************
def cmd_match_start():
	tokens = {}
	userid = es.getcmduserid()
	player = playerlib.getPlayer(userid)

	enabled = es.ServerVar("soccer_mod_allowed")
	if enabled == 1:
		check = es.ServerVar("sm_match_say_command_start_match_on")
		if check == 1:
			start_match_check(userid)
		else:
			steamid = es.getplayersteamid(userid)
			check = int(es.keygetvalue("soccer_mod_admins", steamid, "match"))
			if check == 1:
				start_match_check(userid)
			else:
				es.tell(userid, "#green", messages("start_off", tokens, player.get("lang")))
	else:
		es.tell(userid, "#green", common("not_allowed", tokens, player.get("lang")))

def cmd_match_pause():
	tokens = {}
	userid = es.getcmduserid()
	player = playerlib.getPlayer(userid)

	enabled = es.ServerVar("soccer_mod_allowed")
	if enabled == 1:
		check = es.ServerVar("sm_match_say_command_pause_match_on")
		if check == 1:
			pause_match(userid)
		else:
			steamid = es.getplayersteamid(userid)
			check = int(es.keygetvalue("soccer_mod_admins", steamid, "match"))
			if check == 1:
				pause_match(userid)
			else:
				es.tell(userid, "#green", messages("pause_off", tokens, player.get("lang")))
	else:
		es.tell(userid, "#green", common("not_allowed", tokens, player.get("lang")))

def cmd_match_unpause():
	tokens = {}
	userid = es.getcmduserid()
	player = playerlib.getPlayer(userid)

	enabled = es.ServerVar("soccer_mod_allowed")
	if enabled == 1:
		check = es.ServerVar("sm_match_say_command_pause_match_on")
		if check == 1:
			unpause_match(userid)
		else:
			steamid = es.getplayersteamid(userid)
			check = int(es.keygetvalue("soccer_mod_admins", steamid, "match"))
			if check == 1:
				unpause_match(userid)
			else:
				es.tell(userid, "#green", messages("unpause_off", tokens, player.get("lang")))
	else:
		es.tell(userid, "#green", common("not_allowed", tokens, player.get("lang")))

def cmd_match_stop():
	tokens = {}
	userid = es.getcmduserid()
	player = playerlib.getPlayer(userid)

	enabled = es.ServerVar("soccer_mod_allowed")
	if enabled == 1:
		check = es.ServerVar("sm_match_say_command_stop_match_on")
		if check == 1:
			stop_match(userid)
		else:
			steamid = es.getplayersteamid(userid)
			check = int(es.keygetvalue("soccer_mod_admins", steamid, "match"))
			if check == 1:
				stop_match(userid)
			else:
				es.tell(userid, "#green", messages("stop_off", tokens, player.get("lang")))
	else:
		es.tell(userid, "#green", common("not_allowed", tokens, player.get("lang")))

# ******************** Popup choices ********************
def popup_match_start(userid, choice, popupid):
	start_match_check(userid)
	popuplib.send("sm_popup_admin_match", userid)

def popup_match_stop(userid, choice, popupid):
	stop_match(userid)
	popuplib.send("sm_popup_admin_match", userid)

def popup_match_pause(userid, choice, popupid):
	pause_match(userid)
	popuplib.send("sm_popup_admin_match", userid)

def popup_match_unpause(userid, choice, popupid):
	unpause_match(userid)
	popuplib.send("sm_popup_admin_match", userid)

# ******************** Functions ********************
def lang_msg(text, tokens, center = 0):
	myPlayerList = playerlib.getPlayerList("#human")
	for player in myPlayerList:
		if center == 0:
			es.tell(player.userid, "#green", messages(text, tokens, player.get("lang")))
		else:
			es.centertell(player.userid, messages(text, tokens, player.get("lang")))

def tell_all(message):
	myPlayerList = playerlib.getPlayerList("#human")
	for player in myPlayerList:
		es.centertell(player.userid, message)

def start_match_check(userid):
	tokens = {}
	player = playerlib.getPlayer(userid)

	check = es.ServerVar("cap_fight")
	if check == 0:
		check = es.ServerVar("sm_training_cannon_on")
		if check == 0:
			check = es.ServerVar("sm_training_goals_disabled")
			if check == 0:
				check = es.ServerVar("match")
				if check == 0:
					exists = es.exists("keygroup", "sm_keygroup_vote")
					if exists == 0:
						name = es.getplayername(userid)

						check = es.ServerVar("sm_match_ready_vote_on")
						if check == 1:
							tokens["name"] = name
							lang_msg("ready_vote_started", tokens)

							es.set("sm_vote_question", messages("ready_to_play"))
							es.set("sm_vote_all", 0)
							es.set("sm_vote_block", "soccer_mod_2010/match/start_match")

							es.doblock("soccer_mod_2010/vote/start")
						else:
							tokens = {}
							tokens["name"] = name
							lang_msg("match_started", tokens)

							start_match()
					else:
						es.tell(userid, "#green", messages("vote_active", tokens, player.get("lang")))
				else:
					es.tell(userid, "#green", messages("already_started", tokens, player.get("lang")))
			else:
				es.tell(userid, "#green", messages("no_match_goals_disabled", tokens, player.get("lang")))
		else:
			es.tell(userid, "#green", messages("no_match_cannon_on", tokens, player.get("lang")))
	else:
		es.tell(userid, "#green", messages("no_match_cap_fight", tokens, player.get("lang")))

def start_match():
	es.set("match", 1)
	es.set("match_paused", 0)
	es.set("period", 1)
	es.set("period_time", 1)
	es.set("minutes", 0)
	es.set("seconds", 0)
	es.set("period_running", 0)
	es.set("period_break_running", 0)
	es.set("sm_match_score_t", 0)
	es.set("sm_match_score_ct", 0)
	es.set("sm_match_subs_t", 0)
	es.set("sm_match_subs_ct", 0)
	es.set("golden_goal", 0)
	es.set("sm_match_first_hit", 1)

	es.keygroupdelete("soccer_mod_stats")
	es.keygroupcreate("soccer_mod_stats")
	es.doblock("soccer_mod_2010/match/stats/reset_team_stats")

	number = random.randint(0, 1)
	es.set("match_toss", number)

	periods = int(es.ServerVar("sm_match_number_periods"))
	if periods < 3:
		es.set("score_board_period", messages("half_time"))
	else:
		es.set("score_board_period", messages("period_break"))

	check = es.ServerVar("sm_match_swap_home_away_on")
	name_t = es.ServerVar("sm_match_name_t")
	name_ct = es.ServerVar("sm_match_name_ct")
	if check == 0:
		message = "%s - %s" % (name_t, name_ct)
	else:
		message = "%s - %s" % (name_ct, name_t)
	es.msg("#green", message)

	period_length = int(es.ServerVar("sm_match_period_length"))
	match_length = periods * period_length

	match_minutes = int(math.floor(match_length / 60))
	match_seconds = int(match_length - (match_minutes * 60))

	period_break_length = int(es.ServerVar("sm_match_period_break_length"))

	match_break_minutes = int(math.floor(period_break_length / 60))
	match_break_seconds = int(period_break_length - (match_break_minutes * 60))

	tokens = {}
	tokens["periods"] = periods

	if match_seconds < 10:
		if match_break_seconds < 10:
			tokens["length"] = "%s:0%s" % (match_minutes, match_seconds)
			tokens["break_length"] = "%s:0%s" % (match_break_minutes, match_break_seconds)
		else:
			tokens["length"] = "%s:0%s" % (match_minutes, match_seconds)
			tokens["break_length"] = "%s:%s" % (match_break_minutes, match_break_seconds)
	else:
		if match_break_seconds < 10:
			tokens["length"] = "%s:%s" % (match_minutes, match_seconds)
			tokens["break_length"] = "%s:0%s" % (match_break_minutes, match_break_seconds)
		else:
			tokens["length"] = "%s:%s" % (match_minutes, match_seconds)
			tokens["break_length"] = "%s:%s" % (match_break_minutes, match_break_seconds)

	myPlayerList = playerlib.getPlayerList("#human")
	for ply in myPlayerList:
		cmd = 'usermsg hudhint %s "%s"' % (ply.userid, messages("match_message", tokens, ply.get("lang")))
		es.server.queuecmd(cmd)

	freeze_match()

	es.doblock("soccer_mod_2010/match/stats/score_sheet/reset")

	value = es.ServerVar("sm_match_restart_length")
	cmd = "mp_restartgame %s" % (value)
	es.server.queuecmd(cmd)

def freeze_match():
	myPlayerList = playerlib.getPlayerList("#alive")
	for ply in myPlayerList:
		ply.freeze(1)

	cmd = "phys_pushscale 1"
	es.server.queuecmd(cmd)

	cmd = "phys_timescale 0"
	es.server.queuecmd(cmd)

def stop_match(userid):
	tokens = {}
	player = playerlib.getPlayer(userid)

	check = es.ServerVar("match")
	if check == 1:
		es.set("match", 0)
		es.set("match_paused", 0)
		es.set("period_running", 0)
		es.set("period_break_running", 0)
		es.set("golden_goal", 0)
		es.set("seconds", 0)
		es.set("minutes", 0)
		es.set("period_break_running", 0)

		unfreeze_match()

		name = es.getplayername(userid)
		tokens["name"] = name
		lang_msg("match_stopped", tokens)
	else:
		es.tell(userid, "#green", messages("no_match_started", tokens, player.get("lang")))
		
def unfreeze_match():
	myPlayerList = playerlib.getPlayerList("#alive")
	for ply in myPlayerList:
		ply.freeze(0)

	cmd = "phys_pushscale 900"
	es.server.queuecmd(cmd)

	cmd = "phys_timescale 1"
	es.server.queuecmd(cmd)

def pause_match(userid):
	tokens = {}
	player = playerlib.getPlayer(userid)

	check = es.ServerVar("match")
	if check == 1:
		check = es.ServerVar("match_paused")
		if check == 0:
			es.set("match_paused", 1)

			freeze_match()

			name = es.getplayername(userid)
			tokens["name"] = name
			lang_msg("match_paused", tokens)
		else:
			es.tell(userid, "#green", messages("already_paused", tokens, player.get("lang")))
	else:
		es.tell(userid, "#green", messages("no_match_started", tokens, player.get("lang")))

def unpause_match(userid):
	tokens = {}
	player = playerlib.getPlayer(userid)

	check = es.ServerVar("match")
	if check == 1:
		check = es.ServerVar("match_paused")
		if check == 1:
			check = es.ServerVar("period_break_running")
			if check == 0:
				check = es.ServerVar("match_paused_delay")
				if check == 0:
					es.set("match_paused_delay", 1)

					lang_msg("get_ready", tokens, 1)
					gamethread.delayed(1, tell_all, ("| 5 |"))
					gamethread.delayed(2, tell_all, ("| 4 |"))
					gamethread.delayed(3, tell_all, ("| 3 |"))
					gamethread.delayed(4, tell_all, ("| 2 |"))
					gamethread.delayed(5, tell_all, ("| 1 |"))
					gamethread.delayed(6, lang_msg, ("go", tokens, 1))

					gamethread.delayed(6, unfreeze_match)

					gamethread.delayed(6, es.set, ("match_paused_delay", 0))
					gamethread.delayed(6, es.set, ("match_paused", 0))

					name = es.getplayername(userid)
					tokens["name"] = name

					lang_msg("match_unpaused", tokens)
			else:
				es.set("match_paused_delay", 0)
				es.set("match_paused", 0)

				unfreeze_match()

				name = es.getplayername(userid)
				tokens["name"] = name
				lang_msg("match_unpaused", tokens)
		else:
			es.tell(userid, "#green", messages("already_unpaused", tokens, player.get("lang")))
	else:
		es.tell(userid, "#green", messages("no_match_started", tokens, player.get("lang")))

def delete_popup():
	if popuplib.exists("sm_popup_admin_match"):
		popuplib.delete("sm_popup_admin_match")

# ******************** Unload ********************
def unload():
	delete_popup()

	es.unload("soccer_mod_2010/match/names")
	es.unload("soccer_mod_2010/match/score")
	es.unload("soccer_mod_2010/match/time")

	check = es.ServerVar("sm_module_match_stats_on")
	if check == 1:
		es.unload("soccer_mod_2010/match/stats")