﻿import datetime
from encodings import ascii
import es
import gamethread
import keymenulib
import langlib
import math
import os
import playerlib
import popuplib
import random
import sqlite3
import time

database_exists = os.path.isfile("cstrike/cfg/soccer_mod/ranking.db")

connection = sqlite3.connect("cstrike/cfg/soccer_mod/ranking.db")
cursor = connection.cursor()
connection.text_factory = lambda x: unicode(x, "utf-8", "ignore")

if database_exists != True:
	create_table = "CREATE TABLE [players] ([steamid] VARCHAR(255)  PRIMARY KEY NOT NULL,[name] VARCHAR(255)  NOT NULL,[connected] VARCHAR(255)  NOT NULL,[goals] INTEGER DEFAULT '0' NOT NULL,[assists] INTEGER DEFAULT '0' NOT NULL,[own_goals] INTEGER DEFAULT '0' NOT NULL,[hits] INTEGER DEFAULT '0' NOT NULL,[passes] INTEGER DEFAULT '0' NOT NULL,[interceptions] INTEGER DEFAULT '0' NOT NULL,[losses] INTEGER DEFAULT '0' NOT NULL,[rank] INTEGER DEFAULT '0' NOT NULL)"
	cursor.execute(create_table)

common = langlib.Strings("cstrike/addons/eventscripts/soccer_mod_2010/language/common.ini")
messages = langlib.Strings("cstrike/addons/eventscripts/soccer_mod_2010/language/match/messages_match_stats.ini")
text = langlib.Strings("cstrike/addons/eventscripts/soccer_mod_2010/language/match/popup_stats.ini")

rank_goal = 25
rank_assist = 10
rank_own_goal = -25
rank_hit = 1
rank_pass = 5
rank_interception = 2
rank_loss = -2

shooter_time_stamp = 0
assister_time_stamp = 0

# ******************** Load ********************
def load():
	es.set("sm_stats_debug", 0)
	load_variables()
	reset_team_stats()
	create_popup()
	create_popup_ranking()

	value = random.randint(1, 99999)
	cmd = "sm_event_stats_%s" % (value)
	es.set("sm_event_stats", cmd)
	es.regclientcmd(cmd, "soccer_mod_2010/match/stats/ball_hit", "Ball hit")

	es.keygroupcreate("soccer_mod_stats")

	es.load("soccer_mod_2010/match/stats/score_sheet")

# ******************** Events ********************
def es_map_start(event_var):
	connection.commit()

	reset_team_stats()
	delete_keygroup()
	es.keygroupcreate("soccer_mod_stats")

def player_activate(event_var):
	enabled = es.ServerVar("soccer_mod_allowed")
	if enabled == 1:
		set_connected(event_var["es_username"], event_var["es_steamid"], event_var["userid"])

def player_disconnect(event_var):
	enabled = es.ServerVar("soccer_mod_allowed")
	if enabled == 1:
		set_connected(event_var["es_username"], event_var["es_steamid"], event_var["userid"])

def player_spawn(event_var):
	enabled = es.ServerVar("soccer_mod_allowed")
	if enabled == 1:
		exists = es.exists("key", "soccer_mod_stats", event_var["es_steamid"])
		if exists == 1:
			key_value = es.keygetvalue("soccer_mod_stats", event_var["es_steamid"], "goals")
			cmd = "score set %s %s" % (event_var["userid"], key_value)
			es.server.queuecmd(cmd)

		else:
			cmd = "score set %s 0" % (event_var["userid"])
			es.server.queuecmd(cmd)

def round_start(event_var):
	enabled = es.ServerVar("soccer_mod_allowed")
	if enabled == 1:
		es.set("sm_match_first_hit", 1)
		es.set("sm_stats_round_end", 0)
		es.set("sm_match_goal_scored", 0)

		load_variables()

		players = es.getUseridList()
		length = len(players)
		if length > 0:
			length -= 1
			value = random.randint(0, length)
			userid = players[value]

			es.give(userid, "point_clientcommand")
			event = es.ServerVar("sm_event_stats")

			cmd = 'es_xfire %s func_physbox addoutput "OnDamaged point_clientcommand,command,%s"' % (userid, event)
			es.server.queuecmd(cmd)

			cmd = 'es_xfire %s prop_physics addoutput "OnTakeDamage point_clientcommand,command,%s"' % (userid, event)
			es.server.queuecmd(cmd)

			cmd = 'es_xfire %s trigger_hurt addoutput "OnStartTouch point_servercommand,command,es_xset sm_match_goal_scored 1"' % (userid)
			es.server.queuecmd(cmd)

def round_end(event_var):
	enabled = es.ServerVar("soccer_mod_allowed")
	if enabled == 1:
		gamethread.delayed(0.15, show_stats, (int(event_var["winner"])))

# ******************** Load variables ********************
def load_variables():
	es.set("sm_stats_shooter_userid", 0)
	es.set("sm_stats_shooter_name", 0)
	es.set("sm_stats_shooter_team", 0)
	es.set("sm_stats_shooter_steamid", 0)

	global shooter_time_stamp
	shooter_time_stamp = 0

	es.set("sm_stats_assister_userid", 0)
	es.set("sm_stats_assister_name", 0)
	es.set("sm_stats_assister_team", 0)
	es.set("sm_stats_assister_steamid", 0)

	global assister_time_stamp
	assister_time_stamp = 0

	es.set("sm_stats_winner", 0)

# ******************** Create popups ********************
def create_popup():
	popup = popuplib.create("sm_popup_stats")

	line = "SOCCER MOD %s" % (text("title"))
	popup.addline(line)

	popup.addline(" ")

	line = "->1. %s" % (text("team"))
	popup.addline(line)

	line = "->2. %s" % (text("personal"))
	popup.addline(line)

	line = "->3. %s" % (text("player"))
	popup.addline(line)

	line = "->4. %s" % (text("rankings"))
	popup.addline(line)

	line = "->5. %s" % (text("score_sheet"))
	popup.addline(line)

	popup.addline(" ")

	line = "0. %s" % (common("close"))
	popup.addline(line)

	popup.select(1, team)
	popup.select(2, personal)
	popup.select(3, player)
	popup.submenu(4, "sm_popup_stats_ranking")
	popup.select(5, score_sheet)
	popup.submenu(6, "sm_popup_stats")
	popup.submenu(7, "sm_popup_stats")
	popup.submenu(8, "sm_popup_stats")
	popup.submenu(9, "sm_popup_stats")

def create_popup_ranking():
	popup = popuplib.create("sm_popup_stats_ranking")

	line = "SOCCER MOD %s" % (text("title_rankings"))
	popup.addline(line)

	popup.addline(" ")

	line = "->1. %s" % (text("total"))
	popup.addline(line)

	line = "->2. %s" % (text("goals"))
	popup.addline(line)

	line = "->3. %s" % (text("assists"))
	popup.addline(line)

	line = "->4. %s" % (text("own_goals"))
	popup.addline(line)

	line = "->5. %s" % (text("hits"))
	popup.addline(line)

	line = "->6. %s" % (text("passes"))
	popup.addline(line)

	line = "->7. %s" % (text("interceptions"))
	popup.addline(line)

	line = "->8. %s" % (text("personal"))
	popup.addline(line)

	popup.addline(" ")

	line = "->9. %s" % (common("back"))
	popup.addline(line)

	popup.addline(" ")

	line = "0. %s" % (common("close"))
	popup.addline(line)

	popup.select(1, create_ranking)
	popup.select(2, create_ranking)
	popup.select(3, create_ranking)
	popup.select(4, create_ranking)
	popup.select(5, create_ranking)
	popup.select(6, create_ranking)
	popup.select(7, create_ranking)
	popup.select(8, all_time_personal)
	popup.submenu(9, "sm_popup_stats")

# ******************** Commands ********************
def cmd_stats():
	tokens = {}
	userid = es.getcmduserid()
	player = playerlib.getPlayer(userid)

	enabled = es.ServerVar("soccer_mod_allowed")
	if enabled == 1:
		popuplib.send("sm_popup_stats", userid)
	else:
		es.tell(userid, "#green", common("not_allowed", tokens, player.get("lang")))

# ******************** Popup choices ********************
def team(userid, choice, popupid):
	steamid = es.getplayersteamid(userid)
	
	name = "sm_popup_%s" % (userid)
	if popuplib.exists(name):
		popuplib.delete(name)

	popup = popuplib.create(name)

	line = "SOCCER MOD %s" % (text("title_team"))
	popup.addline(line)

	popup.addline(" ")

	value = es.ServerVar("sm_match_name_t")
	line = "%s:" % (value)
	popup.addline(line)

	popup.addline(" ")

	symbol = "%"
	possession = float(es.ServerVar("sm_stats_total_pos"))
	if possession > 0:
		value = float(es.ServerVar("sm_stats_pos_t"))
		percentage = int(round(((value / possession) * 100), 0))
	else:
		percentage = int(0)

	line = "%s: %s%s" % (text("possession"), percentage, symbol)
	popup.addline(line)

	value = es.ServerVar("sm_stats_number_goals_t")
	line = "%s: %s" % (text("goals"), value)
	popup.addline(line)

	value = es.ServerVar("sm_stats_number_assists_t")
	line = "%s: %s" % (text("assists"), value)
	popup.addline(line)

	value = es.ServerVar("sm_stats_number_own_goals_t")
	line = "%s: %s" % (text("own_goals"), value)
	popup.addline(line)

	value = es.ServerVar("sm_stats_number_hits_t")
	line = "%s: %s" % (text("hits"), value)
	popup.addline(line)

	value = es.ServerVar("sm_stats_number_passes_t")
	line = "%s: %s" % (text("passes"), value)
	popup.addline(line)

	value = es.ServerVar("sm_stats_number_interceptions_t")
	line = "%s: %s" % (text("interceptions"), value)
	popup.addline(line)

	popup.addline(" ")

	value = es.ServerVar("sm_match_name_ct")
	line = "%s:" % (value)
	popup.addline(line)

	popup.addline(" ")

	symbol = "%"
	possession = float(es.ServerVar("sm_stats_total_pos"))
	if possession > 0:
		value = float(es.ServerVar("sm_stats_pos_ct"))
		percentage = int(round((value / possession) * 100))
	else:
		percentage = int(0)

	line = "%s: %s%s" % (text("possession"), percentage, symbol)
	popup.addline(line)

	value = es.ServerVar("sm_stats_number_goals_ct")
	line = "%s: %s" % (text("goals"), value)
	popup.addline(line)

	value = es.ServerVar("sm_stats_number_assists_ct")
	line = "%s: %s" % (text("assists"), value)
	popup.addline(line)

	value = es.ServerVar("sm_stats_number_own_goals_ct")
	line = "%s: %s" % (text("own_goals"), value)
	popup.addline(line)

	value = es.ServerVar("sm_stats_number_hits_ct")
	line = "%s: %s" % (text("hits"), value)
	popup.addline(line)

	value = es.ServerVar("sm_stats_number_passes_ct")
	line = "%s: %s" % (text("passes"), value)
	popup.addline(line)

	value = es.ServerVar("sm_stats_number_interceptions_ct")
	line = "%s: %s" % (text("interceptions"), value)
	popup.addline(line)

	popup.addline(" ")

	line = "->9. %s" % (common("back"))
	popup.addline(line)

	popup.addline(" ")

	line = "0. %s" % (common("close"))
	popup.addline(line)

	popup.select(1, team)
	popup.select(2, team)
	popup.select(3, team)
	popup.select(4, team)
	popup.select(5, team)
	popup.select(6, team)
	popup.select(7, team)
	popup.select(8, team)
	popup.submenu(9, "sm_popup_stats")

	popuplib.send(name, userid)

def personal(userid, choice, popupid):
	tokens = {}
	player = playerlib.getPlayer(userid)

	steamid = es.getplayersteamid(userid)
	exists = es.exists("key", "soccer_mod_stats", steamid)
	if exists == 1:
		name = "sm_popup_%s" % (userid)
		if popuplib.exists(name):
			popuplib.delete(name)

		popup = popuplib.create(name)

		line = "SOCCER MOD %s" % (text("title_personal"))
		popup.addline(line)

		popup.addline(" ")

		symbol = "%"
		possession = float(es.ServerVar("sm_stats_total_pos"))
		if possession > 0:
			value = float(es.keygetvalue("soccer_mod_stats", steamid, "possession"))
			percentage = int(round(((value / possession) * 100), 0))
		else:
			percentage = int(0)

		line = "%s: %s%s" % (text("possession"), percentage, symbol)
		popup.addline(line)

		stats = ["goals", "assists", "own_goals", "hits", "passes", "interceptions"]
		count = 0
		for stat in stats:
			value = float(es.keygetvalue("soccer_mod_stats", steamid, stats[count]))
			string = "sm_stats_number_%s_t" % (stats[count])
			value_t = float(es.ServerVar(string))
			string = "sm_stats_number_%s_ct" % (stats[count])
			value_ct = float(es.ServerVar(string))
			total = value_t + value_ct
			if total > 0:
				percentage = value / total
				percentage *= 100
				number = round(percentage, 0)
				percentage = int(number)
			else:
				percentage = 0

			value = int(value)
			total = int(total)

			line = "%s: %s / %s (%s%s)" % (text(stat), value, total, percentage, symbol)
			popup.addline(line)
			count += 1
			
		popup.addline(" ")

		line = "->9. %s" % (common("back"))
		popup.addline(line)

		popup.addline(" ")

		line = "0. %s" % (common("close"))
		popup.addline(line)

		popup.select(1, personal)
		popup.select(2, personal)
		popup.select(3, personal)
		popup.select(4, personal)
		popup.select(5, personal)
		popup.select(6, personal)
		popup.select(7, personal)
		popup.select(8, personal)
		popup.submenu(9, "sm_popup_stats")

		popuplib.send(name, userid)
	else:
		es.tell(userid, "#green", messages("no_stats", tokens, player.get("lang")))
		popuplib.send("sm_popup_stats", userid)

def player(userid, choice, popupid):
	name = "sm_popup_%s" % (userid)
	if popuplib.exists(name):
		popuplib.delete(name)

	create_player_menu(name, messages("select_player"), "#human", "sm_popup_stats", "player")

	popuplib.send(name, userid)

def create_ranking(userid, choice, popupid):
	if choice == 1:
		type = "rank"
		title = "SOCCER MOD %s %s" % (text("total"), text("ranking"))
	elif choice == 2:
		type = "goals"
		title = "SOCCER MOD %s %s" % (text("goals"), text("ranking"))
	elif choice == 3:
		type = "assists"
		title = "SOCCER MOD %s %s" % (text("assists"), text("ranking"))
	elif choice == 4:
		type = "own_goals"
		title = "SOCCER MOD %s %s" % (text("own_goals"), text("ranking"))
	elif choice == 5:
		type = "hits"
		title = "SOCCER MOD %s %s" % (text("hits"), text("ranking"))
	elif choice == 6:
		type = "passes"
		title = "SOCCER MOD %s %s" % (text("passes"), text("ranking"))
	elif choice == 7:
		type = "interceptions"
		title = "SOCCER MOD %s %s" % (text("interceptions"), text("ranking"))

	es.set("target", 0)
	query_count = "SELECT steamid FROM players WHERE %s > 0" % (type)
	query = "SELECT name, steamid, %s FROM players WHERE %s > 0 ORDER BY %s desc, name asc" % (type, type, type)
	name = "sm_popup_%s" % (userid)
	create_popup_menu(name, title, query_count, query, 0, 1, 0, type)
	popuplib.send(name, userid)

def all_time_personal(userid, choice, popupid):
	name = "sm_popup_%s" % (userid)
	if popuplib.exists(name):
		popuplib.delete(name)

	popup = popuplib.create(name)

	line = "SOCCER MOD %s" % (text("title_all_time_personal"))
	popup.addline(line)

	popup.addline(" ")

	steamid = es.getplayersteamid(userid)
	
	query = "SELECT goals, assists, own_goals, hits, passes, interceptions, rank FROM players WHERE steamid = '%s'" % (steamid)
	cursor.execute(query)
	for row in cursor:
		if row[6] > 0:
			info = get_rank("rank", steamid)
			line = "%s: %s (%s of %s players)" % (text("ranking_points"), row[6], info[0], info[1])
		else:
			line = "%s: no rank yet" % (text("ranking_points"))
		popup.addline(line)

		if row[0] > 0:
			info = get_rank("goals", steamid)
			line = "%s: %s (%s of %s players)" % (text("goals"), row[0], info[0], info[1])
		else:
			line = "%s: no rank yet" % (text("goals"))
		popup.addline(line)

		if row[1] > 0:
			info = get_rank("assists", steamid)
			line = "%s: %s (%s of %s players)" % (text("assists"), row[1], info[0], info[1])
		else:
			line = "%s: no rank yet" % (text("assists"))
		popup.addline(line)

		if row[2] > 0:
			info = get_rank("own_goals", steamid)
			line = "%s: %s (%s of %s players)" % (text("own_goals"), row[2], info[0], info[1])
		else:
			line = "%s: no rank yet" % (text("own_goals"))
		popup.addline(line)

		if row[3] > 0:
			info = get_rank("hits", steamid)
			line = "%s: %s (%s of %s players)" % (text("hits"), row[3], info[0], info[1])
		else:
			line = "%s: no rank yet" % (text("hits"))
		popup.addline(line)

		if row[4] > 0:
			info = get_rank("passes", steamid)
			line = "%s: %s (%s of %s players)" % (text("passes"), row[4], info[0], info[1])
		else:
			line = "%s: no rank yet" % (text("passes"))
		popup.addline(line)

		if row[5] > 0:
			info = get_rank("interceptions", steamid)
			line = "%s: %s (%s of %s players)" % (text("interceptions"), row[5], info[0], info[1])
		else:
			line = "%s: no rank yet" % (text("interceptions"))
		popup.addline(line)

	popup.addline(" ")

	line = "->9. %s" % (common("back"))
	popup.addline(line)

	popup.addline(" ")

	line = "0. %s" % (common("close"))
	popup.addline(line)

	popup.select(1, all_time_personal)
	popup.select(2, all_time_personal)
	popup.select(3, all_time_personal)
	popup.select(4, all_time_personal)
	popup.select(5, all_time_personal)
	popup.select(6, all_time_personal)
	popup.select(7, all_time_personal)
	popup.select(8, all_time_personal)
	popup.submenu(9, "sm_popup_stats_ranking")

	popuplib.send(name, userid)

def score_sheet(userid, choice, popupid):
	tokens = {}
	player = playerlib.getPlayer(userid)

	check = es.ServerVar("sm_stats_score_sheet_number")
	if check > 1:
		popuplib.send("sm_popup_stats_score_sheet_1", userid)
	else:
		es.tell(userid, "#green", messages("empty", tokens, player.get("lang")))
		popuplib.send("sm_popup_stats", userid)

# ******************** Player menu choices ********************
def player_choice(userid, choice, keymenuname):
	tokens = {}
	player = playerlib.getPlayer(userid)

	steamid = es.getplayersteamid(choice)
	exists = es.exists("key", "soccer_mod_stats", steamid)
	if exists == 1:
		name = "sm_popup_%s" % (userid)
		if popuplib.exists(name):
			popuplib.delete(name)

		popup = popuplib.create(name)

		line = "SOCCER MOD %s" % (text("title_player"))
		popup.addline(line)

		popup.addline(" ")

		player_name = es.getplayername(choice)
		line = "%s:" % (player_name)
		popup.addline(line)
		popup.addline(" ")

		symbol = "%"
		possession = float(es.ServerVar("sm_stats_total_pos"))
		if possession > 0:
			value = float(es.keygetvalue("soccer_mod_stats", steamid, "possession"))
			percentage = int(round(((value / possession) * 100), 0))
		else:
			percentage = int(0)

		line = "%s: %s%s" % (text("possession"), percentage, symbol)
		popup.addline(line)

		stats = ["goals", "assists", "own_goals", "hits", "passes", "interceptions"]
		count = 0
		for stat in stats:
			value = float(es.keygetvalue("soccer_mod_stats", steamid, stats[count]))
			string = "sm_stats_number_%s_t" % (stats[count])
			value_t = float(es.ServerVar(string))
			string = "sm_stats_number_%s_ct" % (stats[count])
			value_ct = float(es.ServerVar(string))
			total = value_t + value_ct
			if total > 0:
				percentage = value / total
				percentage *= 100
				number = round(percentage, 0)
				percentage = int(number)
			else:
				percentage = 0

			value = int(value)
			total = int(total)

			line = "%s: %s / %s (%s%s)" % (text(stat), value, total, percentage, symbol)
			popup.addline(line)
			count += 1
			
		popup.addline(" ")

		line = "->9. %s" % (common("back"))
		popup.addline(line)

		popup.addline(" ")

		line = "0. %s" % (common("close"))
		popup.addline(line)

		popup.submenu(9, "sm_popup_stats")

		popuplib.send(name, userid)
	else:
		es.tell(userid, "#green", messages("no_stats", tokens, player.get("lang")))
		popuplib.send("sm_popup_stats", userid)

	name = "sm_popup_%s" % (userid)
	if popuplib.exists(name):
		popuplib.delete(name)

def rank_choice(userid, choice, popupid):
	name = "sm_popup_%s" % (userid)
	target = es.ServerVar("target")
	title = "SOCCER MOD %s %s" % (text("total"), text("ranking"))
	if target != "0":
		create_popup_player(userid, target)
	elif choice == 8:
		result = es.ServerVar("result")
		es.set("target", 0)
		query_count = "SELECT steamid FROM players WHERE rank > 0"
		query = "SELECT name, steamid, rank FROM players WHERE rank > 0 ORDER BY rank desc, name asc"
		create_popup_menu(name, title, query_count, query, 0, 1, result, "rank")
		popuplib.send(name, userid)
	elif choice == 9:
		result = es.ServerVar("result")
		es.set("target", 0)
		query_count = "SELECT steamid FROM players WHERE rank > 0"
		query = "SELECT name, steamid, rank FROM players WHERE rank > 0 ORDER BY rank desc, name asc"
		create_popup_menu(name, title, query_count, query, 0, 1, result, "rank")
		popuplib.send(name, userid)
	elif choice == 10:
		if popuplib.exists(name):
			popuplib.delete(name)
		popuplib.send("sm_popup_stats_ranking", userid)
	elif target == "0":
		popuplib.send(name, userid)

def goals_choice(userid, choice, popupid):
	name = "sm_popup_%s" % (userid)
	target = es.ServerVar("target")
	title = "SOCCER MOD %s %s" % (text("goals"), text("ranking"))
	if target != "0":
		create_popup_player(userid, target)
	elif choice == 8:
		result = es.ServerVar("result")
		es.set("target", 0)
		query_count = "SELECT steamid FROM players WHERE goals > 0"
		query = "SELECT name, steamid, goals FROM players WHERE goals > 0 ORDER BY goals desc, name asc"
		create_popup_menu(name, title, query_count, query, 0, 1, result, "goals")
		popuplib.send(name, userid)
	elif choice == 9:
		result = es.ServerVar("result")
		es.set("target", 0)
		query_count = "SELECT steamid FROM players WHERE goals > 0"
		query = "SELECT name, steamid, goals FROM players WHERE goals > 0 ORDER BY goals desc, name asc"
		create_popup_menu(name, title, query_count, query, 0, 1, result, "goals")
		popuplib.send(name, userid)
	elif choice == 10:
		if popuplib.exists(name):
			popuplib.delete(name)
		popuplib.send("sm_popup_stats_ranking", userid)
	elif target == "0":
		popuplib.send(name, userid)

def assists_choice(userid, choice, popupid):
	name = "sm_popup_%s" % (userid)
	target = es.ServerVar("target")
	title = "SOCCER MOD %s %s" % (text("assists"), text("ranking"))
	if target != "0":
		create_popup_player(userid, target)
	elif choice == 8:
		result = es.ServerVar("result")
		es.set("target", 0)
		query_count = "SELECT steamid FROM players WHERE assists > 0"
		query = "SELECT name, steamid, assists FROM players WHERE assists > 0 ORDER BY assists desc, name asc"
		create_popup_menu(name, title, query_count, query, 0, 1, result, "assists")
		popuplib.send(name, userid)
	elif choice == 9:
		result = es.ServerVar("result")
		es.set("target", 0)
		query_count = "SELECT steamid FROM players WHERE assists > 0"
		query = "SELECT name, steamid, assists FROM players WHERE assists > 0 ORDER BY assists desc, name asc"
		create_popup_menu(name, title, query_count, query, 0, 1, result, "assists")
		popuplib.send(name, userid)
	elif choice == 10:
		if popuplib.exists(name):
			popuplib.delete(name)
		popuplib.send("sm_popup_stats_ranking", userid)
	elif target == "0":
		popuplib.send(name, userid)

def own_goals_choice(userid, choice, popupid):
	name = "sm_popup_%s" % (userid)
	target = es.ServerVar("target")
	title = "SOCCER MOD %s %s" % (text("own_goals"), text("ranking"))
	if target != "0":
		create_popup_player(userid, target)
	elif choice == 8:
		result = es.ServerVar("result")
		es.set("target", 0)
		query_count = "SELECT steamid FROM players WHERE own_goals > 0"
		query = "SELECT name, steamid, own_goals FROM players WHERE own_goals > 0 ORDER BY own_goals desc, name asc"
		create_popup_menu(name, title, query_count, query, 0, 1, result, "own_goals")
		popuplib.send(name, userid)
	elif choice == 9:
		result = es.ServerVar("result")
		es.set("target", 0)
		query_count = "SELECT steamid FROM players WHERE own_goals > 0"
		query = "SELECT name, steamid, own_goals FROM players WHERE own_goals > 0 ORDER BY own_goals desc, name asc"
		create_popup_menu(name, title, query_count, query, 0, 1, result, "own_goals")
		popuplib.send(name, userid)
	elif choice == 10:
		if popuplib.exists(name):
			popuplib.delete(name)
		popuplib.send("sm_popup_stats_ranking", userid)
	elif target == "0":
		popuplib.send(name, userid)

def hits_choice(userid, choice, popupid):
	name = "sm_popup_%s" % (userid)
	target = es.ServerVar("target")
	title = "SOCCER MOD %s %s" % (text("hits"), text("ranking"))
	if target != "0":
		create_popup_player(userid, target)
	elif choice == 8:
		result = es.ServerVar("result")
		es.set("target", 0)
		query_count = "SELECT steamid FROM players WHERE hits > 0"
		query = "SELECT name, steamid, hits FROM players WHERE hits > 0 ORDER BY hits desc, name asc"
		create_popup_menu(name, title, query_count, query, 0, 1, result, "hits")
		popuplib.send(name, userid)
	elif choice == 9:
		result = es.ServerVar("result")
		es.set("target", 0)
		query_count = "SELECT steamid FROM players WHERE hits > 0"
		query = "SELECT name, steamid, hits FROM players WHERE hits > 0 ORDER BY hits desc, name asc"
		create_popup_menu(name, title, query_count, query, 0, 1, result, "hits")
		popuplib.send(name, userid)
	elif choice == 10:
		if popuplib.exists(name):
			popuplib.delete(name)
		popuplib.send("sm_popup_stats_ranking", userid)
	elif target == "0":
		popuplib.send(name, userid)

def passes_choice(userid, choice, popupid):
	name = "sm_popup_%s" % (userid)
	target = es.ServerVar("target")
	title = "SOCCER MOD %s %s" % (text("passes"), text("ranking"))
	if target != "0":
		create_popup_player(userid, target)
	elif choice == 8:
		result = es.ServerVar("result")
		es.set("target", 0)
		query_count = "SELECT steamid FROM players WHERE passes > 0"
		query = "SELECT name, steamid, passes FROM players WHERE passes > 0 ORDER BY passes desc, name asc"
		create_popup_menu(name, title, query_count, query, 0, 1, result, "passes")
		popuplib.send(name, userid)
	elif choice == 9:
		result = es.ServerVar("result")
		es.set("target", 0)
		query_count = "SELECT steamid FROM players WHERE passes > 0"
		query = "SELECT name, steamid, passes FROM players WHERE passes > 0 ORDER BY passes desc, name asc"
		create_popup_menu(name, title, query_count, query, 0, 1, result, "passes")
		popuplib.send(name, userid)
	elif choice == 10:
		if popuplib.exists(name):
			popuplib.delete(name)
		popuplib.send("sm_popup_stats_ranking", userid)
	elif target == "0":
		popuplib.send(name, userid)

def interceptions_choice(userid, choice, popupid):
	name = "sm_popup_%s" % (userid)
	target = es.ServerVar("target")
	title = "SOCCER MOD %s %s" % (text("interceptions"), text("ranking"))
	if target != "0":
		create_popup_player(userid, target)
	elif choice == 8:
		result = es.ServerVar("result")
		es.set("target", 0)
		query_count = "SELECT steamid FROM players WHERE interceptions > 0"
		query = "SELECT name, steamid, interceptions FROM players WHERE interceptions > 0 ORDER BY interceptions desc, name asc"
		create_popup_menu(name, title, query_count, query, 0, 1, result, "interceptions")
		popuplib.send(name, userid)
	elif choice == 9:
		result = es.ServerVar("result")
		es.set("target", 0)
		query_count = "SELECT steamid FROM players WHERE interceptions > 0"
		query = "SELECT name, steamid, interceptions FROM players WHERE interceptions > 0 ORDER BY interceptions desc, name asc"
		create_popup_menu(name, title, query_count, query, 0, 1, result, "interceptions")
		popuplib.send(name, userid)
	elif choice == 10:
		if popuplib.exists(name):
			popuplib.delete(name)
		popuplib.send("sm_popup_stats_ranking", userid)
	elif target == "0":
		popuplib.send(name, userid)

# ******************** Functions ********************
def get_rank(stat, steamid):
	query = "SELECT steamid FROM players WHERE %s > 0 ORDER BY %s desc, name asc" % (stat, stat)
	cursor.execute(query)
	number = 0
	rank = 0
	stop = 0
	for result in cursor:
		number += 1
		if stop == 0:
			rank += 1
			note = result[0]
			check = note.encode("utf-8")
			if check == steamid:
				stop = 1
	info = [rank, number]
	return info

def lang_msg(text, tokens):
	myPlayerList = playerlib.getPlayerList("#human")
	for player in myPlayerList:
		es.tell(player.userid, "#green", messages(text, tokens, player.get("lang")))

def set_connected(name, steamid, userid):
	if steamid != "BOT":
		current = datetime.datetime.now()

		if current.month < 10:
			month = "0%s" % (current.month)
		else:
			month = current.month

		if current.day < 10:
			day = "0%s" % (current.day)
		else:
			day = current.day

		if current.hour < 10:
			hour = "0%s" % (current.hour)
		else:
			hour = current.hour

		if current.minute < 10:
			minute = "0%s" % (current.minute)
		else:
			minute = current.minute

		if current.second < 10:
			second = "0%s" % (current.second)
		else:
			second = current.second

		date = "%s-%s-%s %s:%s:%s" % (current.year, month, day, hour, minute, second)

		query = "SELECT steamid FROM players WHERE steamid = '%s'" % (steamid)
		cursor.execute(query)

		check = 0
		for row in cursor:
			check += 1

		name_enc = name.encode("utf-8")
		if check > 0:
			query = "UPDATE players SET name = '%s', connected = '%s' WHERE steamid = '%s'" % (name_enc, date, steamid)
			cursor.execute(query)
		else:
			query = "INSERT INTO players (name, steamid, connected) VALUES ('%s', '%s', '%s')" % (name_enc, steamid, date)
			cursor.execute(query)

def ball_hit():
	end = es.ServerVar("sm_stats_round_end")
	paused = es.ServerVar("match_paused")
	period_break = es.ServerVar("period_break_running")
	if end == 0 and paused == 0 and period_break == 0:
		es.set("sm_match_first_hit", 0)

		userid = int(es.getcmduserid())
		steamid = es.getplayersteamid(userid)
		team = int(es.getplayerteam(userid))
		name = es.getplayername(userid)

		exists = es.exists("key", "soccer_mod_stats", steamid)
		if exists == 0:
			es.keycreate("soccer_mod_stats", steamid)
			es.keysetvalue("soccer_mod_stats", steamid, "possession", 0)
			es.keysetvalue("soccer_mod_stats", steamid, "goals", 0)
			es.keysetvalue("soccer_mod_stats", steamid, "assists", 0)
			es.keysetvalue("soccer_mod_stats", steamid, "own_goals", 0)
			es.keysetvalue("soccer_mod_stats", steamid, "hits", 0)
			es.keysetvalue("soccer_mod_stats", steamid, "passes", 0)
			es.keysetvalue("soccer_mod_stats", steamid, "interceptions", 0)
			#es.keysetvalue("soccer_mod_stats", steamid, "losses", 0)

		add_stat(steamid, team, "hits", rank_hit)

		shooter_userid = int(es.ServerVar("sm_stats_shooter_userid"))
		shooter_steamid = es.ServerVar("sm_stats_shooter_steamid")
		shooter_team = int(es.ServerVar("sm_stats_shooter_team"))
		shooter_name = es.ServerVar("sm_stats_shooter_name")

		if userid != shooter_userid:
			es.set("sm_stats_assister_userid", shooter_userid)
			es.set("sm_stats_assister_steamid", shooter_steamid)
			es.set("sm_stats_assister_team", shooter_team)
			es.set("sm_stats_assister_name", shooter_name)

			es.set("sm_stats_shooter_userid", userid)
			es.set("sm_stats_shooter_steamid", steamid)
			es.set("sm_stats_shooter_team", team)
			es.set("sm_stats_shooter_name", name)

			global shooter_time_stamp
			global assister_time_stamp
			assister_time_stamp = shooter_time_stamp
			shooter_time_stamp = time.time()

			if shooter_userid > 0:
				if team == shooter_team:
					add_stat(shooter_steamid, shooter_team, "passes", rank_pass)
				else:
					add_stat(steamid, team, "interceptions", rank_interception)
					#add_stat(shooter_steamid, shooter_team, "losses", rank_loss)

				possession = int(shooter_time_stamp - assister_time_stamp)
				if possession > 0:
					add_possession(shooter_steamid, shooter_team, possession)

def show_stats(winner):
	es.set("sm_match_first_hit", 1)
	es.set("sm_stats_round_end", 1)
	es.set("sm_stats_winner", winner)

	shooter_userid = int(es.ServerVar("sm_stats_shooter_userid"))
	shooter_team = int(es.ServerVar("sm_stats_shooter_team"))
	shooter_steamid = es.ServerVar("sm_stats_shooter_steamid")
	shooter_name = es.ServerVar("sm_stats_shooter_name")

	assister_userid = int(es.ServerVar("sm_stats_assister_userid"))
	assister_team = int(es.ServerVar("sm_stats_assister_team"))
	assister_steamid = es.ServerVar("sm_stats_assister_steamid")
	assister_name = es.ServerVar("sm_stats_assister_name")

	check = int(es.ServerVar("sm_match_goal_scored"))
	if check == 1:
		if shooter_userid > 0:
			current = time.time()
			global shooter_time_stamp
			possession = int(current - shooter_time_stamp)

			if possession > 0:
				add_possession(shooter_steamid, shooter_team, possession)

			if shooter_team == winner:
				tokens = {}
				tokens["name"] = shooter_name
				lang_msg("goal", tokens)

				add_stat(shooter_steamid, shooter_team, "goals", rank_goal)

				if assister_team == winner:
					tokens = {}
					tokens["name"] = assister_name
					lang_msg("assist", tokens)

					add_stat(assister_steamid, assister_team, "assists", rank_assist)
			else:
				tokens = {}
				tokens["name"] = shooter_name
				lang_msg("own_goal", tokens)

				add_stat(shooter_steamid, shooter_team, "own_goals", rank_own_goal)

			es.doblock("soccer_mod_2010/match/stats/score_sheet/add")

	check = es.ServerVar("sm_match_stats_save_round_end")
	if check == 1:
		connection.commit()

	load_variables()

def add_stat(steamid, team, type, points):
	if team == 2:
		name = "sm_stats_number_%s_t" % (type)
		value = es.ServerVar(name)
		value += 1
		es.set(name, value)
	elif team == 3:
		name = "sm_stats_number_%s_ct" % (type)
		value = es.ServerVar(name)
		value += 1
		es.set(name, value)

	value = int(es.keygetvalue("soccer_mod_stats", steamid, type))
	value += 1
	es.keysetvalue("soccer_mod_stats", steamid, type, value)

	query = "UPDATE players SET %s = (%s + 1), rank = (rank + %s) WHERE steamid = '%s'" % (type, type, points, steamid)
	cursor.execute(query)

def add_possession(steamid, team, possession):
	if team == 2:
		value = es.ServerVar("sm_stats_pos_t")
		value += possession
		es.set("sm_stats_pos_t", value)
	elif team == 3:
		value = es.ServerVar("sm_stats_pos_ct")
		value += possession
		es.set("sm_stats_pos_ct", value)

	value = es.ServerVar("sm_stats_total_pos")
	value += possession
	es.set("sm_stats_total_pos", value)

	value = int(es.keygetvalue("soccer_mod_stats", steamid, "possession"))
	value += possession
	es.keysetvalue("soccer_mod_stats", steamid, "possession", value)

def reset_team_stats():
	es.set("sm_stats_pos_t", 0)
	es.set("sm_stats_pos_ct", 0)
	es.set("sm_stats_total_pos", 0)

	es.set("sm_stats_number_goals_t", 0)
	es.set("sm_stats_number_goals_ct", 0)

	es.set("sm_stats_number_assists_t", 0)
	es.set("sm_stats_number_assists_ct", 0)

	es.set("sm_stats_number_own_goals_t", 0)
	es.set("sm_stats_number_own_goals_ct", 0)

	es.set("sm_stats_number_hits_t", 0)
	es.set("sm_stats_number_hits_ct", 0)

	es.set("sm_stats_number_passes_t", 0)
	es.set("sm_stats_number_passes_ct", 0)

	es.set("sm_stats_number_interceptions_t", 0)
	es.set("sm_stats_number_interceptions_ct", 0)

	es.set("sm_stats_number_losses_t", 0)
	es.set("sm_stats_number_losses_ct", 0)

def create_popup_player(userid, steamid):
	name = "sm_popup_%s" % (userid)
	if popuplib.exists(name):
		popuplib.delete(name)

	popup = popuplib.create(name)

	line = "SOCCER MOD %s" % (text("title_all_time_player"))
	popup.addline(line)

	popup.addline(" ")

	query = "SELECT name, goals, assists, own_goals, hits, passes, interceptions, rank, connected FROM players WHERE steamid = '%s'" % (steamid)
	cursor.execute(query)
	for row in cursor:
		line = "%s:" % (row[0])
		popup.addline(line)

		popup.addline(" ")

		line = "%s: %s" % (text("last_connected"), row[8])
		popup.addline(line)

		if row[7] > 0:
			info = get_rank("rank", steamid)
			line = "%s: %s (%s of %s players)" % (text("ranking_points"), row[7], info[0], info[1])
		else:
			line = "%s: no rank yet" % (text("ranking_points"))
		popup.addline(line)

		if row[1] > 0:
			info = get_rank("goals", steamid)
			line = "%s: %s (%s of %s players)" % (text("goals"), row[1], info[0], info[1])
		else:
			line = "%s: no rank yet" % (text("goals"))
		popup.addline(line)

		if row[2] > 0:
			info = get_rank("assists", steamid)
			line = "%s: %s (%s of %s players)" % (text("assists"), row[2], info[0], info[1])
		else:
			line = "%s: no rank yet" % (text("assists"))
		popup.addline(line)

		if row[3] > 0:
			info = get_rank("own_goals", steamid)
			line = "%s: %s (%s of %s players)" % (text("own_goals"), row[3], info[0], info[1])
		else:
			line = "%s: no rank yet" % (text("own_goals"))
		popup.addline(line)

		if row[4] > 0:
			info = get_rank("hits", steamid)
			line = "%s: %s (%s of %s players)" % (text("hits"), row[4], info[0], info[1])
		else:
			line = "%s: no rank yet" % (text("hits"))
		popup.addline(line)

		if row[5] > 0:
			info = get_rank("passes", steamid)
			line = "%s: %s (%s of %s players)" % (text("passes"), row[5], info[0], info[1])
		else:
			line = "%s: no rank yet" % (text("passes"))
		popup.addline(line)

		if row[6] > 0:
			info = get_rank("interceptions", steamid)
			line = "%s: %s (%s of %s players)" % (text("interceptions"), row[6], info[0], info[1])
		else:
			line = "%s: no rank yet" % (text("interceptions"))
		popup.addline(line)

	popup.addline(" ")

	line = "->9. %s" % (common("back"))
	popup.addline(line)

	popup.addline(" ")

	line = "0. %s" % (common("close"))
	popup.addline(line)

	popup.submenu(9, "sm_popup_stats_ranking")

	popuplib.send(name, userid)

def create_player_menu(name, title, users, cancelmenu, block):
	if block == "player":
		myPopup = popuplib.easymenu(name, None, player_choice)
	myPopup.settitle(title)

	myPlayerList = playerlib.getPlayerList(users)
	for player in myPlayerList:
		myPopup.addoption(player.userid, player.name)

	myPopup.submenu(10, cancelmenu)

def create_popup_menu(name, title, query_count, query, menu, value, result, block):
	if popuplib.exists(name):
		popuplib.delete(name)

	popup = popuplib.create(name)
	popup.addline(title)
	popup.addline(" ")

	cursor.execute(query_count)

	number = 0
	for row in cursor:
		number += 1

	results = float(number)
	pages = int(math.ceil(results / 7))
	page = (result / 7) + 1

	temp_results = int(results)
	temp_result = result + 1
	temp_result2 = result + 7
	if temp_result2 > temp_results:
		temp_result2 = temp_results

	query_limit = "%s LIMIT %s, 7" % (query, result)
	cursor.execute(query_limit)

	number = 0
	position = temp_result
	for row in cursor:
		number += 1
		note = row[menu]
		check = note.encode("utf-8")
		line = "->%s. %s %s" % (position, row[2], check)
		popup.addline(line)
		popup.menuvalue("target", number, row[value])
		position += 1

	popup.addline(" ")
	tokens = {}
	tokens["page"] = page
	tokens["pages"] = pages
	popup.addline(text("pages", tokens))

	tokens = {}
	tokens["start"] = temp_result
	tokens["end"] = temp_result2
	tokens["results"] = temp_results
	popup.addline(text("results", tokens))

	if results > 7:
		popup.addline(" ")

	back = result - 7
	if back < 0:
		back = 0
	else:
		line = "->8. %s" % (common("previous"))
		popup.addline(line)

	popup.menuvalue("result", 8, back)

	next = result + 7
	if next >= results:
		next = result
	else:
		line = "->9. %s" % (common("next"))
		popup.addline(line)

	popup.menuvalue("result", 9, next)

	popup.addline(" ")

	line = "0. %s" % (common("cancel"))
	popup.addline(line)

	if block == "rank":
		popup.menuselect = rank_choice
	elif block == "goals":
		popup.menuselect = goals_choice
	elif block == "assists":
		popup.menuselect = assists_choice
	elif block == "own_goals":
		popup.menuselect = own_goals_choice
	elif block == "hits":
		popup.menuselect = hits_choice
	elif block == "passes":
		popup.menuselect = passes_choice
	elif block == "interceptions":
		popup.menuselect = interceptions_choice

def delete_keygroup():
	exists = es.exists("keygroup", "soccer_mod_stats")
	if exists == 1:
		es.keygroupdelete("soccer_mod_stats")

def delete_popup_ranking():
	if popuplib.exists("sm_popup_stats_ranking"):
		popuplib.delete("sm_popup_stats_ranking")

# ******************** Unload ********************
def unload():
	connection.commit()
	connection.close()

	delete_keygroup()
	popuplib.delete("sm_popup_stats")
	delete_popup_ranking()

	cmd = es.ServerVar("sm_event_stats")
	es.unregclientcmd(cmd)

	es.unload("soccer_mod_2010/match/stats/score_sheet")