﻿import es
import gamethread
import langlib
import playerlib
import popuplib

common = langlib.Strings("cstrike/addons/eventscripts/soccer_mod_2010/language/common.ini")
messages = langlib.Strings("cstrike/addons/eventscripts/soccer_mod_2010/language/referee/messages_referee.ini")

# ******************** Load ********************
def load():
	create_popup()

	enabled = es.ServerVar("sm_module_referee_warn_on")
	if enabled == 1:
		es.load("soccer_mod_2010/referee/warn")

	enabled = es.ServerVar("sm_module_referee_punish_on")
	if enabled == 1:
		es.load("soccer_mod_2010/referee/punish")

# ******************** Events ********************
def es_map_start(event_var):
	exists = es.exists("keygroup", "soccer_mod_yellow_card")
	if exists == 1:
		es.keygroupdelete("soccer_mod_yellow_card")

	exists = es.exists("keygroup", "soccer_mod_red_card")
	if exists == 1:
		es.keygroupdelete("soccer_mod_red_card")

def player_spawn(event_var):
	enabled = es.ServerVar("soccer_mod_allowed")
	if enabled == 1:
		steamid = es.getplayersteamid(event_var["userid"])
		exists = es.exists("key", "soccer_mod_red_card", steamid)
		if exists == 1:
			change_team(event_var["userid"])

# ******************** Create popup ********************
def create_popup():
	text = langlib.Strings("cstrike/addons/eventscripts/soccer_mod_2010/language/referee/popup_admin_referee.ini")

	popup = popuplib.create("sm_popup_admin_referee")

	line = "SOCCER MOD %s" % (text("title"))
	popup.addline(line)

	popup.addline(" ")

	number = 1

	enabled = es.ServerVar("sm_module_referee_warn_on")
	if enabled == 1:
		line = "->%s. %s" % (number, text("warn"))
		popup.addline(line)
		popup.submenu(number, "sm_popup_admin_referee_warn")
		number += 1

	line = "->%s. %s" % (number, text("yellow"))
	popup.addline(line)
	popup.select(number, yellow)
	number += 1

	line = "->%s. %s" % (number, text("red"))
	popup.addline(line)
	popup.select(number, red)
	number += 1

	line = "->%s. %s" % (number, text("clear"))
	popup.addline(line)
	popup.select(number, clear_cards)
	number += 1

	enabled = es.ServerVar("sm_module_referee_punish_on")
	if enabled == 1:
		line = "->%s. %s" % (number, text("punish"))
		popup.addline(line)
		popup.submenu(number, "sm_popup_admin_referee_punish")
		number += 1

	popup.addline(" ")

	line = "->9. %s" % (common("back"))
	popup.addline(line)

	popup.addline(" ")

	line = "->0. %s" % (common("close"))
	popup.addline(line)

	while number < 9:
		popup.submenu(number, "sm_popup_admin_referee")
		number += 1

	popup.submenu(9, "sm_popup_admin")

# ******************** Popup choices ********************
def yellow(userid, choice, popupid):
	name = "sm_popup_%s" % (userid)
	if popuplib.exists(name):
		popuplib.delete(name)

	create_player_menu(name, messages("select_player_yellow"), "#human", "sm_popup_admin_referee", "yellow")

	popuplib.send(name, userid)

def red(userid, choice, popupid):
	name = "sm_popup_%s" % (userid)
	if popuplib.exists(name):
		popuplib.delete(name)

	name = "sm_popup_%s" % (userid)
	create_player_menu(name, messages("select_player_red"), "#human", "sm_popup_admin_referee", "red")

	popuplib.send(name, userid)

def clear_cards(userid, choice, popupid):
	exists = es.exists("keygroup", "soccer_mod_yellow_card")
	if exists == 1:
		es.keygroupdelete("soccer_mod_yellow_card")

	exists = es.exists("keygroup", "soccer_mod_red_card")
	if exists == 1:
		es.keygroupdelete("soccer_mod_red_card")

	name = es.getplayername(userid)
	tokens = {}
	tokens["name"] = name
	lang_msg("clear", tokens)

	popuplib.send("sm_popup_admin_referee", userid)

# ******************** Player menu choices ********************
def yellow_choice(userid, choice, popupname):
	tokens = {}
	player = playerlib.getPlayer(userid)

	steamid = es.getplayersteamid(choice)
	exists = es.exists("key", "soccer_mod_red_card", steamid)
	if exists == 0:
		exists = es.exists("keygroup", "soccer_mod_yellow_card")
		if exists == 0:
			es.keygroupcreate("soccer_mod_yellow_card")

		exists = es.exists("key", "soccer_mod_yellow_card", steamid)
		if exists == 0:
			es.keycreate("soccer_mod_yellow_card", steamid)
		else:
			exists = es.exists("keygroup", "soccer_mod_red_card")
			if exists == 0:
				es.keygroupcreate("soccer_mod_red_card")

			es.keycreate("soccer_mod_red_card", steamid)

		name = es.getplayername(userid)
		target = es.getplayername(choice)

		exists = es.exists("key", "soccer_mod_red_card", steamid)
		if exists == 0:
			sound = es.ServerVar("sm_referee_sound_whistle")
			es.cexec_all("playgamesound", sound)

			tokens = {}
			tokens["name"] = name
			tokens["target"] = target
			lang_msg("yellow_given", tokens)
		else:
			sound = es.ServerVar("sm_referee_sound_whistle")
			play_sound(sound)
			sound = es.ServerVar("sm_referee_sound_red_card")
			gamethread.delayed(0.5, play_sound, (sound))

			gamethread.delayed(6, change_team, (choice))

			tokens = {}
			tokens["name"] = name
			tokens["target"] = target
			lang_msg("2nd_yellow_given", tokens)
	else:
		es.tell(userid, "#green", messages("already_red", tokens, player.get("lang")))

	name = "sm_popup_%s" % (userid)
	if popuplib.exists(name):
		popuplib.delete(name)

	popuplib.send("sm_popup_admin_referee", userid)

def red_choice(userid, choice, popupid):
	tokens = {}
	player = playerlib.getPlayer(userid)

	steamid = es.getplayersteamid(choice)
	exists = es.exists("key", "soccer_mod_red_card", steamid)
	if exists == 0:
		exists = es.exists("keygroup", "soccer_mod_red_card")
		if exists == 0:
			es.keygroupcreate("soccer_mod_red_card")

		es.keycreate("soccer_mod_red_card", steamid)

		sound = es.ServerVar("sm_referee_sound_whistle")
		play_sound(sound)
		sound = es.ServerVar("sm_referee_sound_red_card")
		gamethread.delayed(0.5, play_sound, (sound))

		gamethread.delayed(6, change_team, (choice))

		name = es.getplayername(userid)
		target = es.getplayername(choice)

		tokens = {}
		tokens["name"] = name
		tokens["target"] = target
		lang_msg("red_given", tokens)
	else:
		es.tell(userid, "#green", messages("already_red", tokens, player.get("lang")))

	name = "sm_popup_%s" % (userid)
	if popuplib.exists(name):
		popuplib.delete(name)

	popuplib.send("sm_popup_admin_referee", userid)

# ******************** Functions ********************
def lang_msg(text, tokens):
	myPlayerList = playerlib.getPlayerList("#human")
	for player in myPlayerList:
		es.tell(player.userid, "#green", messages(text, tokens, player.get("lang")))

def play_sound(sound):
	es.cexec_all("playgamesound", sound)

def change_team(userid):
	player = playerlib.getPlayer(userid)
	if player.team > 1:
		cmd = "es_changeteam %s 1" % (userid)
		es.server.queuecmd(cmd)

def create_player_menu(name, title, users, cancelmenu, block):
	if block == "yellow":
		myPopup = popuplib.easymenu(name, None, yellow_choice)
	elif block == "red":
		myPopup = popuplib.easymenu(name, None, red_choice)
	myPopup.settitle(title)

	myPlayerList = playerlib.getPlayerList(users)
	for player in myPlayerList:
		myPopup.addoption(player.userid, player.name)

	myPopup.submenu(10, cancelmenu)

# ******************** Unload ********************
def unload():
	exists = es.exists("keygroup", "soccer_mod_yellow_card")
	if exists == 1:
		es.keygroupdelete("soccer_mod_yellow_card")

	exists = es.exists("keygroup", "soccer_mod_red_card")
	if exists == 1:
		es.keygroupdelete("soccer_mod_red_card")

	popuplib.delete("sm_popup_admin_referee")

	enabled = es.ServerVar("sm_module_referee_warn_on")
	if enabled == 1:
		es.unload("soccer_mod_2010/referee/warn")

	enabled = es.ServerVar("sm_module_referee_punish_on")
	if enabled == 1:
		es.unload("soccer_mod_2010/referee/punish")